class DataStore {
    constructor(vehicles) {
        this.vehicles = vehicles;
        this.subscribers = [];
        this.filters = {};
        this.notifySubscribers();
    }

    subscribe(subscriber) {
        this.subscribers.push(subscriber);
    }

    unsubscribe(subscriber) {
        this.subscribers = this.subscribers.filter((s) => s !== subscriber);
    }

    unsubscribeAll() {
        this.subscribers = [];
    }

    notifySubscribers(filteredVehicles = this.vehicles) {
        const activeFilters = Object.keys(this.filters);
        if (activeFilters.length > 0) {
            filteredVehicles = this.filterVehicles(filteredVehicles);
        }

        this.subscribers.forEach((subscriber) => {
            subscriber(filteredVehicles);
        });
    }

    addFilter(type, value) {
        this.filters[type] = this.filters[type] || [];
        this.filters[type].push(value);

        this.notifySubscribers();
    }

    removeFilter(type, value) {
        if (this.filters[type]) {
            this.filters[type] = this.filters[type].filter((filter) => filter !== value);
            if (this.filters[type].length === 0) {
                delete this.filters[type];
            }

            this.notifySubscribers();
        }
    }

    filterVehicles(vehicles = this.vehicles) {
        return vehicles.filter((vehicle) => {
            for (const [type, values] of Object.entries(this.filters)) {
                if(Array.isArray(vehicle[type])){
                    if(vehicle[type].some(value => values.includes(value))){
                        return true;
                    }
                }
                if (!values.includes(vehicle[type])) {
                    return false;
                }
            }
            return true;
        });
    }

    getAppliedFilters() {
        return Object.entries(this.filters).map(([type, values]) => ({ type, values }));

    }

    sortBy(property, order) {
        this.vehicles.sort((a, b) => {
            const aValue = a[property];
            const bValue = b[property];

            if (order === 'asc') {
                return aValue > bValue ? 1 : -1;
            } else {
                return bValue > aValue ? 1 : -1;
            }
        });

        this.notifySubscribers();
    }

}
